@@ -13,7 +13,7 @@
 get_mrc_paths <- function(filenames) {
 
   for (i in seq_along(filenames)) {
-    filenames[i] <- get_mrc_path(filenames[i]) # nolint internal function
+    filenames[i] <- mauricer::get_mrc_path(filenames[i])
   }
 
   filenames
