@@ -3,23 +3,27 @@
 #' @return nothing. It does install the BEAST2 package
 #' @author Richèl J.C. Bilderbeek
 #' @examples
-#'   library(testthat)
+#' library(testthat)
 #'
-#'   # Only install a package on Travis, if BEAST2 is installed
-#'   # and the package is not
-#'   if (is_on_travis() &&
-#'     is_beast2_installed()
-#'     && !is_beast2_pkg_installed("NS")
-#'   ) {
-#'     install_beast2_pkg("NS")
-#'     expect_true(is_beast2_pkg_installed("NS"))
+#' # Only install a package on Travis, if BEAST2 is installed
+#' # and the package is not
+#' if (is_on_travis() &&
+#'   is_beast2_installed() &&
+#'   curl::has_internet() &&
+#'   !is_beast2_pkg_installed("Beasy")
+#' ) {
+#'   install_beast2_pkg("Beasy")
+#'   expect_true(is_beast2_pkg_installed("Beasy"))
 #'
-#'     uninstall_beast2_pkg("NS")
-#'     expect_false(is_beast2_pkg_installed("NS"))
-#'   }
+#'   uninstall_beast2_pkg("Beasy")
+#'   expect_false(is_beast2_pkg_installed("Beasy"))
+#' }
 #' @export
 uninstall_beast2_pkg <- function(name) {
-  if (!is_beast2_pkg_installed(name)) {
+  if (!curl::has_internet()) {
+    stop("No internet connection")
+  }
+  if (isFALSE(is_beast2_pkg_installed(name))) {
     stop("Cannot uninstall absent package")
   }
   # java -cp beast.jar beast.util.PackageManager -add bacter
@@ -35,13 +39,3 @@ uninstall_beast2_pkg <- function(name) {
     stdout = FALSE
   )
 }
-
-#' Obsolete function to uninstall a BEAST2 package.
-#' Use \link{uninstall_beast2_pkg} instead
-#' @param name the package's name
-#' @return nothing. It does install the BEAST2 package
-#' @author Richèl J.C. Bilderbeek
-#' @export
-mrc_uninstall <- function(name = NA) {
-  stop("'mrc_uninstall' is deprecated, use 'uninstall_beast2_pkg' instead")
-}
